EpochBoundaryVerifier

Struct EpochBoundaryVerifier 

pub struct EpochBoundaryVerifier { /* private fields */ }
Verifies the last checkpoint of each listed epoch against the committee of that epoch.

A verifier is defined by a starting committee and the sequence numbers of the checkpoints to verify; the committee advances as each checkpoint is verified.

Examples

use iota_config::{genesis::Genesis, node::ArchiveReaderConfig};
use iota_data_ingestion_core::history::{reader::HistoricalReader, verifier::EpochBoundaryVerifier};

let reader = HistoricalReader::new(config)?;
let genesis = Genesis::load(genesis_path)?;

let target_epoch = 1000;
let verifier = EpochBoundaryVerifier::from_genesis(reader, &genesis, target_epoch).await?;
let target = verifier.verify_target_epoch_boundary().await?;
println!("verified last checkpoint of epoch {}", target.epoch());

Implementations

Source

impl EpochBoundaryVerifier

pub async fn new( reader: HistoricalReader, starting_committee: Committee, target_epoch: EpochId, ) -> Result<Self>

Creates a verifier from a starting committee for the target epoch.

Errors

Fails if the target epoch precedes the starting committee’s epoch, or if the epoch boundaries cannot be read from the remote store.

pub async fn from_genesis( reader: HistoricalReader, genesis: &Genesis, target_epoch: EpochId, ) -> Result<Self>

Creates a verifier for the target epoch, whose starting committee is the genesis committee.

Errors

Fails if the epoch boundaries cannot be read from the remote store.

pub async fn verify_target_epoch_boundary(self) -> Result<VerifiedCheckpoint>

Verifies the last checkpoint of the given epoch.

This consumes the verifier, draining the stream returned by Self::stream_verified_checkpoints.

Errors

Fails if Self::stream_verified_checkpoints fails.

pub async fn stream_verified_checkpoints( self, ) -> Result<impl Stream<Item = Result<VerifiedCheckpoint>> + Send>

Streams the verified last checkpoints from the starting committee’s epoch up to the target epoch of the verifier.

This consumes the verifier. Each checkpoint is fetched into memory and verified only when the stream is polled. Upon successful verification the committee is advanced to verify the last checkpoint of the next epoch.

Errors

Generating the stream only fails if the MANIFEST in the remote store cannot be synced.

The stream returns an error in the following occasions:

  • If the last checkpoint of the next epoch is not recorded in the epoch boundaries.
  • If the summary cannot be fetched from the remote store
  • If signature verification fails
  • If the checkpoint is not the last checkpoint of the epoch